summaryrefslogtreecommitdiffstats
path: root/kopete/kopete/chatwindow/kopetechatwindow.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit2bc1d72869b62af05ae4feafd878203b526da8c5 (patch)
tree2676903bb600bd9646644856e354940471ad84e2 /kopete/kopete/chatwindow/kopetechatwindow.cpp
parent937b2991d8e78166eea904c80ad04d34607017a4 (diff)
downloadtdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.tar.gz
tdenetwork-2bc1d72869b62af05ae4feafd878203b526da8c5.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kopete/kopete/chatwindow/kopetechatwindow.cpp')
-rw-r--r--kopete/kopete/chatwindow/kopetechatwindow.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/kopete/chatwindow/kopetechatwindow.cpp b/kopete/kopete/chatwindow/kopetechatwindow.cpp
index e88c13cc..f2dbd24a 100644
--- a/kopete/kopete/chatwindow/kopetechatwindow.cpp
+++ b/kopete/kopete/chatwindow/kopetechatwindow.cpp
@@ -164,8 +164,8 @@ KopeteChatWindow *KopeteChatWindow::window( Kopete::ChatSession *manager )
return myWindow;
}
-KopeteChatWindow::KopeteChatWindow( TQWidget *tqparent, const char* name )
- : KParts::MainWindow( tqparent, name )
+KopeteChatWindow::KopeteChatWindow( TQWidget *parent, const char* name )
+ : KParts::MainWindow( parent, name )
{
m_activeView = 0L;
m_popupView = 0L;
@@ -406,7 +406,7 @@ void KopeteChatWindow::initActions(void)
if( !animIcon.isNull() ) //and another QT bug: it crash if we pause a null movie
animIcon.pause();
// we can't set the tool bar as tqparent, if we do, it will be deleted when we configure toolbars
anim = new TQLabel( TQString(), 0L ,"kde toolbar widget" );
anim->setMargin(5);
anim->setPixmap( normalIcon );
@@ -406,7 +406,7 @@ void KopeteChatWindow::initActions(void)
if( !animIcon.isNull() ) //and another QT bug: it crash if we pause a null movie
animIcon.pause();
- // we can't set the tool bar as tqparent, if we do, it will be deleted when we configure toolbars
+ // we can't set the tool bar as parent, if we do, it will be deleted when we configure toolbars
anim = new TQLabel( TQString(), 0L ,"kde toolbar widget" );
anim->setMargin(5);